﻿using UnityEngine;
using System.Collections;

using UnityEngine.UI;
using System;

public class EndOfGameUI : MonoBehaviour
{
    public Text EndStatusTitleText;
    public Sprite PinkSprite;
    public Sprite PurpleSprite;
    public Sprite GreenSprite;
    public Sprite YellowSprite;
    public Button ReturnToLobbyButton;

    public Text MyScoreText;
    public Text[] ScoreTexts;
    public Image[] ScoreImages;

    private int _textIndex = 0;
    private string _endstatusText;

    void OnEnable()
    {
        StartCoroutine(AnimateEndOfGame());
        ReturnToLobbyButton.onClick.AddListener(OnReturnToLobbyClicked);
    }

    void OnDisable()
    {
        ReturnToLobbyButton.onClick.RemoveListener(OnReturnToLobbyClicked);
    }

    private void ResetText()
    {
        MyScoreText.text = "-";
        EndStatusTitleText.text = string.Empty;
        ReturnToLobbyButton.gameObject.SetActive(false);
        var enemyControllers = BottomGameManager.Instance.EnemyControllers;
        for (int i = 0; i < enemyControllers.Length; i++)
        {
            ScoreTexts[i].text = "-";
            ScoreImages[i].transform.parent.gameObject.SetActive(false);
        }
    }

    private IEnumerator AnimateEndOfGame()
    {
        ResetText();
        CheckWhoWon();

        float waitTime = 0.2f;
        yield return new WaitForSeconds(waitTime);
        MyScoreText.text = string.Format("SCORE: {0}", BottomGameManager.Instance.MyScore);
        AudioManager.Instance.PlayAudioClip(AudioManager.Clip.ResultsClip);
        yield return new WaitForSeconds(waitTime);
        var enemyControllers = BottomGameManager.Instance.EnemyControllers;
        for (int i = 0; i < enemyControllers.Length; i++)
        {
            ScoreTexts[i].text = enemyControllers[i].PlayerText.text;
            ScoreImages[i].sprite = GetIconForPlayer(enemyControllers[i].PlayerColor);
            ScoreImages[i].transform.parent.gameObject.SetActive(true);
            AudioManager.Instance.PlayAudioClip(AudioManager.Clip.ResultsClip);
            yield return new WaitForSeconds(waitTime);
        }

        yield return new WaitForSeconds(waitTime);
        while (_textIndex < _endstatusText.Length)
        {
            _textIndex++;
            EndStatusTitleText.text = _endstatusText.Substring(0, _textIndex);
            yield return new WaitForSeconds(0.05f);
        }
        yield return new WaitForSeconds(waitTime);
        ReturnToLobbyButton.gameObject.SetActive(true);
    }

    private void CheckWhoWon()
    {
        bool isADrawGame = false;
        var enemyControllers = BottomGameManager.Instance.EnemyControllers;
        for (int i = 0; i < enemyControllers.Length; i++)
        {
            isADrawGame = isADrawGame && BottomGameManager.Instance.MyScore == int.Parse(enemyControllers[i].PlayerText.text);
        }
        _endstatusText = string.Empty;
        if (isADrawGame)
        {
            _endstatusText = "DRAW";
        }
        else
        {
            bool hasWon = true;
            for (int i = 0; i < enemyControllers.Length; i++)
            {
                hasWon = hasWon && BottomGameManager.Instance.MyScore >= int.Parse(enemyControllers[i].PlayerText.text);
            }
            _endstatusText = hasWon ? "You Win!" : "You Lose!";
        }
    }


    private void OnReturnToLobbyClicked()
    {
        PUNManager.Instance.LeaveAndGotoWelcome();
        AudioManager.Instance.PlayAudioClip(AudioManager.Clip.SelectionClip);
    }

    public Sprite GetIconForPlayer(BottomGameManager.PlayerColors playerColor)
    {
        switch (playerColor)
        {
            case BottomGameManager.PlayerColors.Green:
                return GreenSprite;
            case BottomGameManager.PlayerColors.Pink:
                return PinkSprite;
            case BottomGameManager.PlayerColors.Purple:
                return PurpleSprite;
            case BottomGameManager.PlayerColors.Yellow:
                return YellowSprite;
            default:
                Debug.LogErrorFormat("No sprite set for {0}", playerColor);
                return GreenSprite;
        }
    }
}