﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections.Generic;

public class LobbyUI : MonoBehaviour
{
    public Text NoGamesText;
    public ScrollRect ServersScrollRect;
    public Button CloseButton;
    public Button CreateRoomButton;
    public Transform ContentTransform;
    public JoinRoomButton JoinRoomButtonPrefab;

    private List<JoinRoomButton> _joinRoomButtonInstances;

    private void Start()
    {
        _joinRoomButtonInstances = new List<JoinRoomButton>();
        InvokeRepeating("RefreshLobby", 0, 2);
    }

    void OnEnable()
    {
        CreateRoomButton.interactable = true;
        CloseButton.onClick.AddListener(OnCloseButtonClicked);
        CreateRoomButton.onClick.AddListener(OnCreateNewRoomButton);
    }

    void OnDisable()
    {
        CloseButton.onClick.RemoveListener(OnCloseButtonClicked);
        CreateRoomButton.onClick.RemoveListener(OnCreateNewRoomButton);
    }

    private void OnCloseButtonClicked()
    {
        UIManager.Instance.ShowScreen(UIManager.UIScreen.Welcome);
    }

    void RefreshLobby()
    {
        foreach (var joinRoomButton in _joinRoomButtonInstances)
        {
            joinRoomButton.gameObject.SetActive(false);
        }

        if (PhotonNetwork.connected && !PhotonNetwork.inRoom)
        {
            CreateJoinRoomButtonInstance();
            var roomList = PhotonNetwork.GetRoomList();
            NoGamesText.gameObject.SetActive(true);
            ServersScrollRect.gameObject.SetActive(false);
            for (int i = 0; i < roomList.Length; i++)
            {
                if (roomList[i].IsOpen)
                {
                    NoGamesText.gameObject.SetActive(false);
                    ServersScrollRect.gameObject.SetActive(true);
                    _joinRoomButtonInstances[i].RoomName = roomList[i].Name;
                    _joinRoomButtonInstances[i].ServerNameText.text = roomList[i].Name;
                    _joinRoomButtonInstances[i].CountOfPlayerText.text = string.Format("{0}/{1}", roomList[i].PlayerCount, roomList[i].MaxPlayers);
                    _joinRoomButtonInstances[i].gameObject.SetActive(true);
                }
            }
        }
    }

    private void CreateJoinRoomButtonInstance()
    {
        int countToCreate = PhotonNetwork.GetRoomList().Length - _joinRoomButtonInstances.Count;
        for (int i = 0; i < countToCreate; i++)
        {
            var newJoinRoomInstance = Instantiate(JoinRoomButtonPrefab, ContentTransform);
            _joinRoomButtonInstances.Add(newJoinRoomInstance);
        }
    }

    private void OnCreateNewRoomButton()
    {
        CreateRoomButton.interactable = false;
        RoomOptions roomOptions = new RoomOptions()
        {
            MaxPlayers = PUNManager.MAX_PLAYERS
        };
        TypedLobby typedLobby = new TypedLobby()
        {
            Type = LobbyType.Default
        };
        PhotonNetwork.JoinOrCreateRoom(((RoomName)PhotonNetwork.GetRoomList().Length + 1).ToString(), roomOptions, typedLobby);
        AudioManager.Instance.PlayAudioClip(AudioManager.Clip.SelectionClip);
    }

    private enum RoomName
    {
        Radio,
        Radiation,
        Ultrasound,
        Microwave,
        Mechanical,
        Transverse,
        Light,
        Sonar,
        Electromagnetic,
    }
}