﻿using System;
using System.Collections.Generic;
using UnityEngine;

public class QuestionManager : Singleton<QuestionManager>
{
    public TextAsset QuestionsCSV;

    public class QuestionData
    {
        public string Question;
        public List<string> Answers = new List<string>();
        public string CorrectAnswer;
        public int Points;
    }

    public List<QuestionData> QuestionList = new List<QuestionData>();
    private List<QuestionData> _currentQuestionList = new List<QuestionData>();
    private const char CSV = ',';

    protected override void Awake()
    {
        base.Awake();

        ParseData();
    }


    public void Init()
    {
        _currentQuestionList = new List<QuestionData>(QuestionList);
    }


    public int GetRandomQuestionIndex()
    {
        var index = UnityEngine.Random.Range(0, _currentQuestionList.Count);
        var questionData = _currentQuestionList[index];
        _currentQuestionList.RemoveAt(index);
        return QuestionList.IndexOf(questionData);
    }

    private void ParseData()
    {
        var csvLines = QuestionsCSV.text.SplitByLine(true);
        var csvLine = string.Empty;

        for (int i = 0; i < csvLines.Length; i++)
        {
            csvLine = csvLines[i];
            var csvLineEntries = csvLine.Split(new char[] { CSV }, StringSplitOptions.RemoveEmptyEntries);
            QuestionList.Add(new QuestionData()
            {
                Question = csvLineEntries[0],
                CorrectAnswer = csvLineEntries[1],
                Answers = new List<string>()
                {
                   csvLineEntries[1], csvLineEntries[2], csvLineEntries[3]
                },
                Points = int.Parse(csvLineEntries[4])
            });
        }
    }

    public QuestionData GetQuestion(int index)
    {
        return QuestionList[index];
    }
}