﻿using UnityEngine;
using UnityEngine.UI;

public class TopGameManager : Singleton<TopGameManager>
{
    public Text QuestionText;
    public Text[] AnswerTexts;
    public Button[] AnswerButtons;
    public Image TimerFillBarImage;
    public CanvasGroup TopGroupCanvasGroup;

    public const float TIME_TO_ANSWER_QUESTION = 5f;
    private QuestionManager.QuestionData _questionData;
    private float _timeRemaining;
    private QuestionManager.QuestionData _nextQuestion;
    private bool _isGameRunning = false;

    protected override void Awake()
    {
        base.Awake();
        AnswerButtons[0].onClick.AddListener(() => { OnAnswerButtonClicked(0); });
        AnswerButtons[1].onClick.AddListener(() => { OnAnswerButtonClicked(1); });
        AnswerButtons[2].onClick.AddListener(() => { OnAnswerButtonClicked(2); });
    }

    public void Update()
    {
        if (!_isGameRunning)
        {
            return;
        }

        if (_timeRemaining > 0)
        {
            _timeRemaining -= Time.deltaTime;
            UpdateFillBar();
        }
        else
        {
            SetNextQuestion();
        }
    }

    public void StartGame()
    {
        _isGameRunning = true;
        SetNextQuestion();
    }

    public void StopGame()
    {
        _isGameRunning = false;
        _questionData = null;
        _nextQuestion = null;
    }

    private void SetNextQuestion()
    {
        _timeRemaining = TIME_TO_ANSWER_QUESTION;
        _questionData = _nextQuestion;
        UpdateQuestionData();
        TopGroupCanvasGroup.alpha = 1.0f;
        TopGroupCanvasGroup.interactable = true;
        PUNManager.Instance.SetNextQuestion(TIME_TO_ANSWER_QUESTION * 0.5f);
    }

    private void UpdateQuestionData()
    {
        QuestionText.text = _questionData.Question;
        var answers = _questionData.Answers;
        answers.Shuffle();

        for (int i = 0; i < AnswerTexts.Length; i++)
        {
            AnswerTexts[i].text = _questionData.Answers[i];
        }

        foreach (var button in AnswerButtons)
        {
            button.interactable = true;
        }
    }

    private void UpdateFillBar()
    {
        float delta = _timeRemaining / TIME_TO_ANSWER_QUESTION;
        TimerFillBarImage.fillAmount = delta;
        if (delta < 0.2f)
        {
            TimerFillBarImage.color = new Color(1, 1, 1, 0.25f + Mathf.PingPong(Time.time * (delta * 10), 1));
        }
    }

    private void OnAnswerButtonClicked(int i)
    {
        if (string.Compare(AnswerTexts[i].text, _questionData.CorrectAnswer, true) == 0)
        {
            BottomGameManager.Instance.IncreaseProgress(_questionData.Points);
            AudioManager.Instance.PlayAudioClip(AudioManager.Clip.GoodAnswerClip);
        }
        else
        {
            Handheld.Vibrate();
            AudioManager.Instance.PlayAudioClip(AudioManager.Clip.BadAnswerClip);
        }

        TopGroupCanvasGroup.alpha = 0.5f;
        TopGroupCanvasGroup.interactable = false;
    }

    public void SetNextQuestion(QuestionManager.QuestionData questionData)
    {
        _nextQuestion = questionData;
    }
}