﻿using System;
using UnityEngine;
using UnityEngine.UI;

public class WaitingForPlayersUI : MonoBehaviour
{
    public Text TitleText;
    public Text RoomNameText;
    public Text PlayerCountText;
    public Button BackToLobbyButton;

    private int _dotCounts;
    private string _dots;
    private bool _isInCountdown;
    private float _timeToStartGame;
    private float COUNTDOWN_BEFORE_STARTING_GAME = 4.0f;

    private void Start()
    {
        InvokeRepeating("AddDots", 0, .5f);
    }

    private void OnEnable()
    {
        BackToLobbyButton.onClick.AddListener(OnBackToLobbyButtonClick);
    }

    private void Update()
    {
        if (PhotonNetwork.inRoom)
        {
            PlayerCountText.text = string.Format("{0} <size=40>of</size> {1} players", PhotonNetwork.room.PlayerCount, PhotonNetwork.room.MaxPlayers);
            RoomNameText.text = string.Format("Waiting for\nplayers in server\n <color=#CC0170FF><{0}>{1}</color>",
                PhotonNetwork.room.Name, _dots);
        }

        if (_isInCountdown)
        {
            _timeToStartGame -= Time.deltaTime;
            TitleText.text = string.Format("STARTING IN {0:0}", _timeToStartGame);

            if (_timeToStartGame < 1.0f)
            {
                if (PhotonNetwork.room.CustomProperties.ContainsKey(PUNManager.NEXT_QUESTION_INDEX))
                {
                    var nextQuestion = QuestionManager.Instance.GetQuestion((int)PhotonNetwork.room.CustomProperties[PUNManager.NEXT_QUESTION_INDEX]);
                    TopGameManager.Instance.SetNextQuestion(nextQuestion);
                }

                UIManager.Instance.BottomGameManagerInstance.StartGame();
                TopGameManager.Instance.StartGame();
                _isInCountdown = false;
                UIManager.Instance.ShowScreen(UIManager.UIScreen.InGame);
            }
        }
    }

    private void OnDisable()
    {
        BackToLobbyButton.onClick.RemoveListener(OnBackToLobbyButtonClick);
    }

    private void OnBackToLobbyButtonClick()
    {
        PhotonNetwork.LeaveRoom();
        UIManager.Instance.ShowScreen(UIManager.UIScreen.Lobby);
        AudioManager.Instance.PlayAudioClip(AudioManager.Clip.SelectionClip);
    }

    private void AddDots()
    {
        _dotCounts++;
        _dotCounts %= 4;
        _dots = "....".Substring(0, _dotCounts);
    }

    public void StartCountDownToStartGame()
    {
        _isInCountdown = true;
        _timeToStartGame = COUNTDOWN_BEFORE_STARTING_GAME;
    }
}