﻿using System.Collections;
using UnityEngine;
using UnityEngine.UI;

public class WelcomeUI : MonoBehaviour
{
    public Text CreditsText;
    public RollerCredits RollerCredits;
    public AnimationCurve CreditsTextCurve;

    public Text StatusText;
    public Button StartGameButton;

    private void Awake()
    {
        Invoke("RollingCredits", 2.0f);
    }

    void OnEnable()
    {
        StartGameButton.onClick.AddListener(OnStartGameButtonClicked);
    }

    void OnDisable()
    {
        StartGameButton.onClick.RemoveListener(OnStartGameButtonClicked);
    }

    private void OnStartGameButtonClicked()
    {
        UIManager.Instance.ShowScreen(UIManager.UIScreen.Lobby);
        AudioManager.Instance.PlayAudioClip(AudioManager.Clip.SelectionClip);
    }


    private void RollingCredits()
    {
        RollerCredits.Setup();
        Invoke("RollingCredits", Random.Range(3f, 4f));
    }

    public void ShowCreditsText(BottomGameManager.PlayerColors playerColor)
    {
        CreditsText.text = GetPlayerCreditsText(playerColor);
        CreditsText.transform.localPosition = Vector3.zero;
        StartCoroutine(CreditsTextAnimation());
    }

    private IEnumerator CreditsTextAnimation()
    {
        var timer = 0f;
        var delta = 0f;
        var position = CreditsText.transform.localPosition;

        while (delta != 1f)
        {
            timer += Time.deltaTime;
            delta = Mathf.Clamp01(timer / 1f);
            position.y = CreditsTextCurve.Evaluate(delta);
            CreditsText.transform.localPosition = position;
            yield return new WaitForEndOfFrame();
        }
    }

    private string GetPlayerCreditsText(BottomGameManager.PlayerColors playerColor)
    {
        switch (playerColor)
        {
            case BottomGameManager.PlayerColors.Green:
                return "Dylan";
            case BottomGameManager.PlayerColors.Pink:
                return "Lynda";
            case BottomGameManager.PlayerColors.Purple:
                return "Marlon";
            case BottomGameManager.PlayerColors.Yellow:
                return "Anthony";
            default:
                return "";
        }
    }

    public void PlayGlitchSound()
    {
        AudioManager.Instance.PlayAudioClip(AudioManager.Clip.BadHitClip);
    }

}
